@@ -12,7 +12,7 @@ from requests.auth import HTTPBasicAuth
 import yaml
 import time
 
-VERSION = '0.4.1'
+VERSION = '0.4.2'
 
 backliftURL = {}
 default_backliftURL = 'https://www.backlift.com/'
@@ -219,20 +219,12 @@ def read_api_key():
 
 ## REQUESTS -------------------------------------------------------------------
 
-def register_key(key):
-    # import pdb; pdb.set_trace()
-    try:
-        r = requests.post(backliftURL['register'], 
-                          data={'access_key': key}, verify=False)
-        check_response(r)
-    except requests.exceptions.ConnectionError:
-        fail(ERR_SERVER)
-
-
 def get_app_meta(api_key, app_id):
     try:
         # import pdb; pdb.set_trace()
-        r = requests.get(backliftURL['getappmeta'] % app_id, 
+        headers = {'x-requested-with': 'BackliftCLI',
+                   'x-cli-version': VERSION}
+        r = requests.get(backliftURL['getappmeta'] % app_id, headers=headers,
                           auth=HTTPBasicAuth('api', api_key), verify=False)
         check_response(r)
 
@@ -248,10 +240,12 @@ def get_app_meta(api_key, app_id):
 def create_app(api_key, name, template):
     try:
         # import pdb; pdb.set_trace()
+        headers = {'x-requested-with': 'BackliftCLI',
+                   'x-cli-version': VERSION}
         r = requests.post(backliftURL['create'], 
                           data={'appname': name, 'template': template},
                           auth=HTTPBasicAuth('api', api_key), 
-                          verify=False)
+                          verify=False, headers=headers)
         check_response(r)
 
         r = json.loads(r.text)
@@ -266,7 +260,9 @@ def create_app(api_key, name, template):
 def delete_app(api_key, app_id):
     try:
         # import pdb; pdb.set_trace()
-        r = requests.delete(backliftURL['delete'] % app_id,
+        headers = {'x-requested-with': 'BackliftCLI',
+                   'x-cli-version': VERSION}
+        r = requests.delete(backliftURL['delete'] % app_id, headers=headers,
                             auth=HTTPBasicAuth('api', api_key), verify=False)
         check_response(r)
 
@@ -280,7 +276,8 @@ def create_superuser(api_key, app_id, username, password):
     try:
         # import pdb; pdb.set_trace()
         data={'username': username, 'password': password}
-        headers = {'x-requested-with': 'BackliftAPI'}
+        headers = {'x-requested-with': 'BackliftCLI',
+                   'x-cli-version': VERSION}
         res = requests.post(backliftURL['createsuperuser'] % app_id, 
                           auth=HTTPBasicAuth('api', api_key), verify=False,
                           headers=headers, data=data)
@@ -300,9 +297,12 @@ def download_template_files(path, template, api_key, params=None):
     try:
         # import pdb; pdb.set_trace()
 
+        headers = {'x-requested-with': 'BackliftCLI',
+                   'x-cli-version': VERSION}
         manifest_url = os.path.join(backliftURL['templatefiles'], template)
         r = requests.get(manifest_url, 
-                         auth=HTTPBasicAuth('api', api_key), verify=False)
+                         auth=HTTPBasicAuth('api', api_key), verify=False,
+                         headers=headers)
         check_response(r)
 
         r = json.loads(r.text)
@@ -313,7 +313,8 @@ def download_template_files(path, template, api_key, params=None):
 
                 file_url = os.path.join(backliftURL['templatefiles'], template, f)
                 r = requests.get(file_url, params=params, 
-                                 auth=HTTPBasicAuth('api', api_key), verify=False)
+                                 auth=HTTPBasicAuth('api', api_key), verify=False,
+                                 headers=headers)
                 check_response(r)
 
                 filepath = os.path.abspath(os.path.join(path, f))
@@ -331,8 +332,11 @@ def download_template_files(path, template, api_key, params=None):
 
 def upload_files(id, files, api_key):
     try:
+        headers = {'x-requested-with': 'BackliftCLI',
+                   'x-cli-version': VERSION}
         r = requests.post(backliftURL['upload'] % id, files=files,
-                          auth=HTTPBasicAuth('api', api_key), verify=False)
+                          auth=HTTPBasicAuth('api', api_key), verify=False,
+                          headers=headers)
 
         for filekey, filedata in files.items():
             filedata[1].close()
@@ -356,19 +360,16 @@ def setup(api_key):
     save_api_key(api_key)
 
 
-def register(key):
-    register_key(key)
-
-
-def create(path, name, template='init'):
+def create(path, name, template='init', mkpath=True):
 
     # import pdb; pdb.set_trace()
 
     api_key = read_api_key()
 
-    app_root = os.path.normpath(
-                    os.path.abspath(
-                        os.path.join(path, name)))
+    app_root = os.path.normpath(os.path.abspath(path))
+
+    if mkpath:
+        app_root = os.path.normpath(os.path.join(app_root, name))
 
     cfg_path = os.path.join(app_root, backlift_configfile)
 
@@ -417,8 +418,8 @@ def delete(path, name, force=False):
         fail(ERR_BADID)
 
 
-def init(path):
-    create(path)
+def init(path, name):
+    create(path, name, mkpath=False)
 
 
 def push(path, skip_hidden):
@@ -521,7 +522,7 @@ def execute_command_line():
         '  setup API_KEY\t\tAuthorize this computer with your API_KEY\n' +\
         '  create NAME\t\tCreate a new basic backlift app in the NAME folder\n' +\
         '  create:TYPE NAME\tCreate a new backlift app using the TYPE template\n' +\
-        '  init\t\t\tInitialize backlift for an existing app\n' +\
+        '  init NAME\t\tInitialize a backlift app at the given --path (default: current folder)\n' +\
         '  push\t\t\tPush files up to backlift\n' +\
         '  watch\t\t\tObserve path and push files to backlift whenever they change\n' +\
         '  open\t\t\tOpen an app using the default browser\n' +\
@@ -545,8 +546,6 @@ def execute_command_line():
 
     (options, args) = parser.parse_args()
 
-
-
     backlift_root = options.url
     backliftURL['register'] = os.path.join(backlift_root, 'register-early')
     backliftURL['getappmeta'] = os.path.join(backlift_root, 'app-admin/%s')
@@ -585,7 +584,10 @@ def execute_command_line():
                 appname = args[1]
             delete(options.path, appname, options.force)
         elif args[0].lower() == 'init':
-            init(options.path)
+            if len(args) != 2:
+                parser.print_help()
+            else:
+                init(options.path, args[1])
         elif args[0].lower() == 'open':
             open_browser(options.path)
         elif args[0].lower() == 'admin':
